Crate sphinxad_sys [−] [src]
Structs
| ad_rec_t |
Device |
Constants
| AD_EOF | |
| AD_ERR_GEN | |
| AD_ERR_NOT_OPEN | |
| AD_ERR_WAVE | |
| AD_OK | |
| DEFAULT_SAMPLES_PER_SEC |
Uses for ad_open function |
Functions
| ad_close |
Close the recording device. |
| ad_open |
Open the default audio device. |
| ad_open_dev |
Open a specific audio device with a given name and sampling rate. |
| ad_open_sps |
Open the default audio device with a given sampling rate. |
| ad_read |
Read next block of audio samples while recording; read upto max samples into buf. |
| ad_start_rec |
Start audio recording. |
| ad_stop_rec |
Stop audio recording. |